# un-comment to make access to stats staff-only
#$c->{irstats_restricted_access} = 1;
# if restricted, un-comment to allow access to graphs on abstract pages
#$c->{irstats_allow_abstracts_graphs} = 1;

# default security check, return 1 or 0 to allow request to access stats
$c->{irstats_allow_request} = sub 
{
	my( $eprints_session ) = @_;

	if( defined $eprints_session && $eprints_session->config( "irstats_restricted_access" ) )
	{
		if( $eprints_session->config( "irstats_allow_abstracts_graphs" ) )
		{
			# let the request go if we're coming from an abstract page
			my $referer = EPrints::Apache::AnApache::header_in(
                                $eprints_session->get_request,
                                'Referer' );
			my $base_url = $eprints_session->config( 'base_url' );
			if( defined $referer && $referer =~ m#^$base_url/\d+/?$# )	#
			{
				# ok, request comes from an abstract page
				return 1;
			}
		}
		
		return 1 if( defined $eprints_session->current_user );
	}
	else
	{
		return 1;
	}

	return 0;
};


$c->{irstats_abstract_content} = sub
{
	my ($session, $eprint) = @_;

	my $frag = $session->make_doc_fragment;

	my $repository = $session->get_repository;

        my @documents = $eprint->get_all_documents();
        my $docs_to_show = scalar @documents;

	if ($docs_to_show > 0)
	{
		$frag->appendChild($repository->call('irstats_js', $session));

                my $div = $session->make_element( "div", class=>"ep_block" );
                $frag->appendChild( $div );
                my $h2 = $session->make_element( "h2" );
                $h2->appendChild( $session->make_text( "Document Downloads" ) );
                $div->appendChild( $h2 );

		my $graph1_div = $session->make_element('div', id => 'irstats_graph1');
		$div->appendChild($graph1_div);
		my $graph2_div = $session->make_element('div', id => 'irstats_graph2');
		$div->appendChild($graph2_div);

		$div->appendChild($repository->call(
			'insert_irstats_view',
			$session,
			'irstats_graph2',
			$repository->call('irstats_eprint_monthly_downloads_params', $eprint->get_id)
		));

		$div->appendChild($repository->call(
			'insert_irstats_view',
			$session,
			'irstats_graph1',
			$repository->call('irstats_eprint_daily_downloads_params', $eprint->get_id)
		));

		$div->appendChild($session->get_repository->call('irstats_dashboard_link', $session, $eprint));

	}

	return $frag;
};

# MePrints widget
$c->{irstats_meprints_content} = sub
{
	my ($session, $user) = @_;

	my $frag = $session->make_doc_fragment;

	$frag->appendChild($session->call('irstats_js', $session));

	my $div = $session->make_element( "div", class=>"ep_block" );
	$frag->appendChild( $div );

	my $graph1_div = $session->make_element('div', id => 'irstats_graph_meprints');
	$div->appendChild($graph1_div);

	$div->appendChild($session->call(
		'insert_irstats_view',
		$session,
		'irstats_graph_meprints',
		$session->call('irstats_meprints_monthly_downloads_params', $user->get_id)
	));

	return $frag;
};


$c->{irstats_dashboard_link} = sub
{
	my ($session, $dataobj) = @_;

	$dataobj = 'dummy' unless defined $dataobj; #so ref returns a string

	my $base_url = '/cgi/irstats.cgi';
	my $cgi_args = { page => 'db' };
	my $link_text = 'IRStats Dashboard';


	if (ref $dataobj eq 'EPrints::DataObj::EPrint')
	{
		$cgi_args->{page} = 'dashboard';
		$cgi_args->{IRS_epchoice} = 'EPrint';
		$cgi_args->{eprint} = $dataobj->get_id;
		$link_text = 'More statistics for this item...'; #will go on abstract page under the graphs
	}

#not difficult, but hard to link into the browse view page
	elsif (ref $dataobj eq 'EPrints::DataObj::Subject')
	{
		$cgi_args->{page} = 'dashboard';
		$cgi_args->{IRS_epchoice} = 'divisions';
		$cgi_args->{divisionss} = 'divisions_' . $dataobj->get_value('subjectid');
		$link_text = 'Download Statistics';
	}


#converting a user into an IRStats author is non-trivial.  Needs some thought.
#       elsif (ref $dataobj eq 'EPrints::DataObj::User')
#       {
#               $cgi_args->{page} = 'dashboard';
#               $cgi_args->{IRS_epchoice} = 'creators_name';
#               $cgi_args->{creators_names} =  ; #e.g. creators_name_638
#
#
#       }

	my @param_pairs;
	foreach my $param (keys %{$cgi_args})
	{
		push @param_pairs, $param . '=' . $cgi_args->{$param};
	}
	my $url = $base_url . '?' . join('&', @param_pairs);
	my $link = $session->make_element('a', href=>$url);
	$link->appendChild($session->make_text($link_text));
	return $link;
};




$c->{irstats_js} = sub
{
	my ($session) = @_;

	return $session->make_javascript('
        function js_irstats_load_stats(div_id,params)
        {
                new Ajax.Request(
                        eprints_http_cgiroot+"/irstats.cgi",
                        {
                                method: "post",
                                onFailure: function() {
                                        //alert( "AJAX request failed..." );
                                },
                                onException: function(req, e) {
                                        //alert( "AJAX Exception " + e );
                                },
                                onSuccess: function(response){
                                        var text = response.responseText;
                                        if( text.length == 0 )
                                        {
                                                //alert( "No response from server..." );
                                        }
                                        else
                                        {
                                                $(div_id).update( response.responseText );
                                        }
                                },
                                parameters: params
                        }
                );
        }
');

};

$c->{insert_irstats_view} = sub
{
	my ($session, $div_id, $params) = @_;

	my @params;
	foreach (keys %{$params})
	{
		push @params, $_ . " : '" . $params->{$_} . "'";
	}
	my $params_string = join(" , ", @params);

	return $session->make_javascript("

        Event.observe(window,'load',function () {
                        js_irstats_load_stats( '$div_id', { $params_string } );
                });
	");
};

$c->{irstats_eprint_daily_downloads_params} = sub
{
	my ($eprintid) = @_;

	return {
		'page' => 'get_view2',
		'IRS_epchoice' => 'EPrint',
		'eprint' => $eprintid,
		'IRS_datechoice' => 'period',
		'period' => '-1m',
		'view' => 'DailyDownloadsGraph',
	};
};

$c->{irstats_eprint_monthly_downloads_params} = sub
{
	my ($eprintid) = @_;

	return {
		'page' => 'get_view2',
		'IRS_epchoice' => 'EPrint',
		'eprint' => $eprintid,
		'IRS_datechoice' => 'period',
		'period' => '-12m',
		'view' => 'MonthlyDownloadsGraph',
	};
};

$c->{irstats_meprints_monthly_downloads_params} = sub
{
	my ($userid) = @_;

	return {
		'page' => 'get_view2',
		'IRS_epchoice' => 'userid',
		'userids' => 'userid_'.$userid,
		'IRS_datechoice' => 'period',
		'period' => '-12m',
		'view' => 'MePrintsDownloadsGraph',
	};
};

#$c->{plugins}->{"Screen::EPrint::IRStatsItemSummary"}->{appears}->{summary_top} = undef;
#$c->{plugins}->{"Screen::EPrint::IRStatsItemSummary"}->{appears}->{summary_right} = undef;
#$c->{plugins}->{"Screen::EPrint::IRStatsItemSummary"}->{appears}->{summary_bottom} = 1000;
#$c->{plugins}->{"Screen::EPrint::IRStatsItemSummary"}->{appears}->{summary_left} = undef; 
