package IRStats::GUI;

use strict;

sub handler
{
	my( $r ) = @_;
	my $eprints_session = EPrints::Session->new();

	# sf2/test if IRStats is enabled on this repository:
	return 0 unless( EPrints::Utils::is_set( $eprints_session->config( 'irstats_js' ) ) );

	my $session = IRStats->new(
		eprints_session => $eprints_session, request => $r
	);

	my %self = (
		session => $session,
	);

	if( $eprints_session->can_call( 'irstats_allow_request' ) && !$eprints_session->call( 'irstats_allow_request', $eprints_session ) )
	{
		my $self = bless \%self, "IRStats::GUI";
		$self->must_login( $eprints_session );
		return 0;
	}

	my $cgi = $session->cgi;

	my $page = $cgi->param( 'page' ) || 'stats';

	my $class = $page;
	$class =~ s/\W+//g;
	$class = "IRStats::GUI::$class";

	eval "use $class";
	if( $@ )
	{
		Carp::confess "No such page [$page]: $@\n";
	}

	binmode(STDOUT,":utf8");

	my $self = bless \%self, $class;
	$self->generate;

	return 0;
}

sub must_login
{
	my( $self, $eprints_session ) = @_;

        my $referer = EPrints::Apache::AnApache::header_in(
                                $eprints_session->get_request,
                                'Referer' );

	$referer = "/cgi/irstats.cgi" unless( defined $referer );

	$self->header;
	$self->start_html;
	print STDOUT <<CONTENT;
	<div>You must <a href="/cgi/users/login?target=$referer">login</a> to access statistics.</div>
CONTENT
	$self->end_html;
}

sub generate
{
	$_[0]->html_page;
}

sub html_page
{
	my( $self ) = @_;

	$self->header;
	$self->start_html;
	$self->body;
	$self->end_html;
}

sub header
{
	my( $self ) = @_;
	
	print $self->{session}->cgi->header('text/html; charset=UTF-8');
}

sub start_html
{
	my( $self ) = @_;
	
	my( $static_url ) = $self->{session}->get_conf->static_url;
	my $title = $self->title;

	print <<EOH;
<html>
<head>
<title>$title</title>
<style type='text/css' media='screen'>
\@import '$static_url/generic.css';
\@import '$static_url/screen.css';
</style>
<style type='text/css' media='print'>
\@import '$static_url/generic.css';
\@import '$static_url/print.css';
</style>
</head>
<body>
EOH

}

sub end_html
{
	my( $self ) = @_;

	print <<EOH;
</body>

</html>
EOH
}

sub title
{
	my( $self ) = @_;

	"IRStats";
}

1;
