package IRStats::View::AllMonthlyDownloadsChart;

use strict;
use warnings;

use IRStats::DatabaseInterface;
use IRStats::Visualisation::Graph::HorizontalBar;
use IRStats::View;
use IRStats::Periods;
use Data::Dumper;

use Locale::Country;

our @ISA = qw(IRStats::View);

sub initialise
{
        my ($self) = @_;
        $self->{'sql_params'} ={
		#columns => [ 'COUNT' ]
		columns => [ 'requester_country', 'COUNT' ],
		group => "requester_country",
		order => {column => "COUNT", direction => "DESC"},
	};
        $self->{'visualisation'} = IRStats::Visualisation::Graph::HorizontalBar->new(
	{
                        filename => $self->{'params'}->get('id') . ".png",
                        title => "Total Downloads",
                        x_title => 'Month',
                        y_title => "Number of Downloads",
                        data_series => [],
			x_labels => [],
			params => $self->{params}
	}
        );
}

sub new
{
        my( $class, $params, $database ) = @_;
        my $self = $class->SUPER::new($params, $database);;
        $self->initialise();
        return $self;
}

sub populate
{
	my ($self) = @_;

##Check Cache
	my $cache = IRStats::Cache->new($self->{'params'});
	if ($cache->exists)
	{
		$self->{'visualisation'} = $cache->read();
		return;
	}

	my $x_labels = [];
	my $x_2_labels = [];
	my $data_series = [];	

	# change start_date to be the earliest date so that "All" periods are considered

	my $sql_query = "select min(datestamp) from irs_access_";
	my $results = $self->{'database'}->do_sql($sql_query);
	my @data = $results->fetchrow_array();
	my $start_date = $data[0]; 
	if (defined $start_date && $start_date =~ /(\d+)-(\d+)-(\d+)/)
	{
		$self->{'params'}->{'start_date'}->set('day',1);
		$self->{'params'}->{'start_date'}->set('month',$2);
		$self->{'params'}->{'start_date'}->set('year',$1);
	}
	else
	{
		$self->{'params'}->{'start_date'}->set('day',1);
		$self->{'params'}->{'start_date'}->set('month',1);
		$self->{'params'}->{'start_date'}->set('year',2008);
	}

	my $periods = IRStats::Periods->new($self->{'params'}->{'start_date'},$self->{'params'}->{'end_date'});
	my $grand_total = 0;
	my $downloaded_flag = 0;
	my @counts;
	foreach my $period ( @{$periods->calandar_months()} )
	{
		$self->{'params'}->mask($period);
	     
		my $query = $self->{'database'}->get_stats(
			$self->{'params'},
			$self->{'sql_params'},
		);
		$self->{'params'}->unmask();

		my $top_n = [];
		while ( my @row = $query->fetchrow_array() )
		{
			push @{$top_n}, \@row ;
		}
		$query->finish(); 

		my $total = 0;
		my $country_count = 0;
		my $major_country;
		my $max_count = 0;

		foreach my $row (@$top_n)
		{
			my $country_code = $row->[0];
			my $count = $row->[1];
			if ($count > $max_count)
			{
				$max_count = $count;
				$major_country = $country_code;
			}
			$country_count++ if ($count > 0);
			$total += $count;
			$grand_total += $count;
		}
		if ($total > 0)
		{
			push @counts, $total;


			my $country_name = code2country($major_country);
			$country_name = 'Unknown' unless $country_name;
			$major_country = 'Unknown' unless $major_country;
			my $flag_url = lc($major_country) . '.png';
			my $flag_img = "<*img=/opt/eprints3/lib/static/irstats/flag_thumbs/png/$flag_url*>";
			my $country_label = $flag_img." ".$max_count." ".$country_name;

			my $x_label = $period->{'start_date'}->month_name()." ".$total;
			$x_label .= " (".$country_count.") ";
			#$x_label .= $country_label;
			if ($period->{'start_date'}->{'month'} == 1 || scalar (@{$x_labels}) == 0)
			{
				$x_label = $period->{'start_date'}->part('year','short')." ".$x_label;
			}
			push @{$x_labels}, $x_label;
			push @{$x_2_labels}, $country_label;
		}
	}
	unshift @{$x_labels}, "Grand Total  ".$grand_total;
	unshift @{$x_2_labels}, " ";
	unshift @counts, 0;  # could add the $grand_total but this results in one big bar and lots of little ones

	push @{$data_series}, { data => \@counts }; 


	$self->{'visualisation'}->set('x_labels',$x_labels);
	$self->{'visualisation'}->set('x_2_labels',$x_2_labels);
	$self->{'visualisation'}->set('x_2_title', "Major Contributor");
	$self->{'visualisation'}->set('data_series',$data_series);
	
##write to cache
	$cache->write($self->{'visualisation'});
}

1;
