package IRStats::View::TopCountriesChart;

use strict;
use warnings;

use IRStats::DatabaseInterface;
use IRStats::Cache;
use IRStats::Visualisation::Graph::HorizontalBar;
use IRStats::View;
use Data::Dumper;

use Locale::Country;

our @ISA = qw/ IRStats::View /;

sub initialise
{
        my ($self) = @_;
	$self->{'sql_params'} = {
		columns => [ 'requester_country', 'COUNT' ],
		group => "requester_country",
		order => {column => "COUNT", direction => "DESC"},
		limit => 50
		#limit => 40
	};

	my $title = "Downloads by Country";
	$title .= " period: ".$self->{params}->{start_month}."/".$self->{params}->{start_year};
	$title .= " - ".$self->{params}->{end_month}."/".$self->{params}->{end_year};

	$self->{'visualisation'} = IRStats::Visualisation::Graph::HorizontalBar->new(
	{
		title => $title,
                filename => $self->{'params'}->get('id') . ".png",
                y_title => $title,
                x_title => "Country",
                data_series => [],
		x_labels => [],
		params => $self->{params}
	}
        );
}

sub new
{
        my( $class, $params, $database ) = @_;
        my $self = $class->SUPER::new($params, $database);;
        $self->initialise();
        return $self;
}

sub populate
{
	my ($self) = @_;
##Check Cache
	my $cache = IRStats::Cache->new($self->{'params'});
	if ($cache->exists)
	{
		$self->{'visualisation'} = $cache->read();
		return;
	}
	my $x_labels = [];
	my $data_series = [];
	
	my $top_n = [];

print STDERR "params: ".Data::Dumper::Dumper( $self->{'params'} )."\n".Data::Dumper::Dumper( $self->{'sql_params'} )."\n";
	my $query = $self->{'database'}->get_stats(
			$self->{'params'},
			$self->{'sql_params'}
			);

	while ( my @row = $query->fetchrow_array() )
	{
		push @{$top_n}, \@row ;
	}
	$query->finish(); 

	my $total = 0;
	my $counts = ();
	foreach my $row (@$top_n)
	{
		my $country_code = $row->[0];
		my $count = $row->[1];
		my $country_name = code2country($country_code);
		$country_name = 'Unknown' unless $country_name;
		$country_code = 'Unknown' unless $country_code;
		my $flag_url = lc($country_code) . '.png';
		my $flag_img = "<*img=/opt/eprints3/lib/static/irstats/flag_thumbs/png/$flag_url*>";
		my $country_label = $country_name." ".$count." ".$flag_img;
		push @{$x_labels}, $country_label;
		push @{$counts}, $count;
		$total += $count;
	}

	my @rev_counts = reverse(@{$counts});
	my @rev_labels = reverse(@{$x_labels});

	push @rev_labels, "Grand Total  ".$total;
	push @rev_counts, $total;

	push @{$data_series}, { data => \@rev_counts }; 
                               # citation => };

	$self->{'visualisation'}->set('x_labels',\@rev_labels);
	$self->{'visualisation'}->set('data_series',$data_series);
	
	##write to cache
	$cache->write($self->{'visualisation'});
}

1;
