package IRStats::View::TopCountriesTable;

use strict;
use warnings;

use IRStats::DatabaseInterface;
use IRStats::Cache;
use IRStats::Visualisation::Table::HTML_Columned;
use IRStats::View;
use Data::Dumper;

use Locale::Country;

our @ISA = qw/ IRStats::View /;

sub initialise
{
        my ($self) = @_;
	$self->{'sql_params'} = {
		columns => [ 'requester_country', 'COUNT' ],
		group => "requester_country",
		order => {column => "COUNT", direction => "DESC"},
		limit => 60
	};
	$self->{'visualisation'} = IRStats::Visualisation::Table::HTML_Columned->new(
	{
		title => "Top Countries",
		columns => [ 'Flag', 'Country', 'Downloads'],
		rows => [],
	}
        );
}

sub new
{
        my( $class, $params, $database ) = @_;
        my $self = $class->SUPER::new($params, $database);;
        $self->initialise();
        return $self;
}

sub populate
{
	my ($self) = @_;
##Check Cache
	my $cache = IRStats::Cache->new($self->{'params'});
	if ($cache->exists)
	{
		$self->{'visualisation'} = $cache->read();
		return;
	}

	my $rows = [];

	my $query = $self->{'database'}->get_stats(
			$self->{'params'},
			$self->{'sql_params'}
			);

	while ( my @row = $query->fetchrow_array() )
	{
		push @{$rows}, \@row ;
	}
	$query->finish(); 

	my $output_rows = [];
	foreach my $row (@$rows)
	{
		my $country_code = $row->[0];
		my $count = $row->[1];
		my $country_name = code2country($country_code);
		$country_name = 'Unknown' unless $country_name;
		$country_code = 'Unknown' unless $country_code;
		my $flag_url = '/irstats/flag_thumbs/png/' . lc($country_code) . '.png';
		my $flag_img = "<img src='$flag_url' alt='$country_code flag' title='$country_code' />";

		push @{$output_rows}, [$flag_img, $country_name, $count]
	}

	$self->{'visualisation'}->set('rows',$output_rows);

	##write to cache
	$cache->write($self->{'visualisation'});
}

1;
