package IRStats::Visualisation::Graph::HorizontalBar;

use strict;

use IRStats::Visualisation::Graph::GraphLegend;
use IRStats::Visualisation::Graph;
use IRStats::Visualisation::Graph::Bar;

our @ISA = qw(IRStats::Visualisation::Graph::Bar);

sub new
{
	my ($class, $data) = @_;
	my $self = $class->SUPER::new($data);
	return $self;
}

sub chartdirector_render
{
	my( $self ) = @_;

	my $c = new XYChart(485, 750, 0xeeeeff, 0x000000, 1);
	$c->setRoundedFrame();
	#$c->addTitle($self->{'title'}, "timesbi.ttf", 15)->setBackground(0xccccff, 0x000000, perlchartdir::glassEffect());

	#Swap the axis so that the bars are drawn horizontally
	$c->swapXY();

	$c->xAxis()->setTitle($self->{'x_title'});
	$c->xAxis()->setLabels($self->{'x_labels'});
	if (defined $self->{'x_2_labels'})
	{
		$c->xAxis2()->setTitle($self->{'x_2_title'});
		$c->xAxis2()->setLabels($self->{'x_2_labels'});
		$c->xAxis2()->setLabelStep(1);
		$c->setPlotArea(100, 25, 275, 670, 0xffffff, -1, -1, 0xcccccc, 0xcccccc);
	} 
	else
	{
		$c->setPlotArea(180, 25, 275, 670, 0xffffff, -1, -1, 0xcccccc, 0xcccccc);
	}
	$c->yAxis()->setTitle($self->{'y_title'});
	$c->yAxis()->setMinTickInc(1); # make y axis always show whole numbers

	{
		use integer;
		$c->xAxis()->setLabelStep(1);
		#$c->xAxis()->setLabelStep((($#{$self->{'x_labels'}}+1)/13)+1);
	}
	my $slayer = $c->addSplineLayer();
	my $layer = $c->addBarLayer2($perlchartdir::Side, 3);
        $layer->setBarShape($perlchartdir::CircleShape);
	foreach my $i (0 .. $#{$self->{'data_series'}})
	{
		$layer->addDataSet($self->{'data_series'}->[$i]->{'data'}, $self->{'colours'}->[$i]);
		if( $self->{'trend'} )
		{
			my $src = $self->{'data_series'}->[$i]->{'data'};
			my $mean = [];
			my $len = scalar @$src;
			my $range = 7;
			for( my $i = 0; $i < $len; ++$i )
			{
				my $c = 0;
				my $t = 0;
				for(my $j = $i-$range; $j <= $i+$range; ++$j)
				{
					next if $j < 0;
					next if $j > $len-1;
					++$c;
					$t += $src->[$j];
				}
				push @$mean, $t / $c;
			}
			$slayer->addDataSet( $mean, 0x00c0c0, "Averaged Trend Line" );
		}
	}
	$layer->setLineWidth(2);
	$slayer->setLineWidth(2);

	my $conf = $self->{params}->get('conf');
	my $path = $conf->get_path('graphs_path').'/'.$self->{filename};

	$c->makeChart( $path ) or die "Error creating graph at '$path': '$!'";

	my $r = "<div class=\"bar_graph\">
		<table><tr>
		<td>
		<img class=\"chart\" src = \"$self->{'url_relative'}\">
		</td>
		";

	if ($self->{data_series}->[0]->{citation})
	{
	my $legend = IRStats::Visualisation::Graph::GraphLegend->new($self->{'data_series'}, $self->{'colours'});
		$r .= "<td>" .
		$legend->render() .
		"</td>";
	}
	$r .= "</tr></table>
		</div>";

	return $r;
}

1;

